@@ -73,17 +73,6 @@ class PlotDataObject(DessiaObject):
         return DessiaObject.dict_to_object(dict_=dict_, force_generic=True)
 
 
-# class ColorMapSet(DessiaObject):
-#     def __init__(self, value: float = None, tooltip: bool = False,
-#                  color_range: str = None, selector: bool = True,
-#                  name: str = ''):
-#         self.selector = selector
-#         self.color_range = color_range
-#         self.tooltip = tooltip
-#         self.value = value
-#         DessiaObject.__init__(self, name=name)
-
-
 class HatchingSet(DessiaObject):
     """
     A class for setting hatchings on a surface.
@@ -101,12 +90,6 @@ class HatchingSet(DessiaObject):
         DessiaObject.__init__(self, name=name)
 
 
-# class ColorSurfaceSet(DessiaObject):
-#     def __init__(self, color: str = 'white', name: str = ''):
-#         self.color = color
-#         DessiaObject.__init__(self, name=name)
-
-
 class Window(DessiaObject):
     def __init__(self, width: float, height: float, name: str = ''):
         self.width = width
@@ -121,14 +104,14 @@ class EdgeStyle(DessiaObject):
     :param line_width: line width in pixels.
     :type line_width: float
     :param color_stroke: the edge's color (rgb255).
-    :type color_stroke: str
+    :type color_stroke: plot_data.Colors.Color
     :param dashline: a list of positive floats [a1,...,an] representing \
     a pattern where a_2i is the number of solid pixels and a_2i+1 is \
     the number of empty pixels.
     :type dashline: List[float]
     """
 
-    def __init__(self, line_width: float = None, color_stroke: str = None,
+    def __init__(self, line_width: float = None, color_stroke: colors.Color = None,
                  dashline: List[int] = None, name: str = ''):
         self.line_width = line_width
         self.color_stroke = color_stroke
@@ -273,16 +256,17 @@ class Line2D(PlotDataObject):
     An infinite line. Line2D is a primitive and can be instantiated by \
     PrimitiveGroups.
 
-    :param data: [x1, y1, x2, y2] where (x1, y1) and (x2, y2) are two \
-    points that belong to the line.
-    :type data: [float, float, float, float]
+    :param point1: first endpoint of the line segment [x1, y1].
+    :type point1: List[float]
+    :param point2: first endpoint of the line segment [x2, y2].
+    :type point2: List[float]
     :param edge_style: for customization
     :type edge_style: EdgeStyle
     """
 
-    def __init__(self, data: List[float], edge_style: EdgeStyle = None,
-                 name: str = ''):
-        self.data = data
+    def __init__(self, point1: List[float], point2: List[float],
+                 edge_style: EdgeStyle = None, name: str = ''):
+        self.data = point1 + point2
         self.edge_style = edge_style
         PlotDataObject.__init__(self, type_='line2d', name=name)
 
@@ -309,16 +293,18 @@ class LineSegment2D(PlotDataObject):
     A line segment. This is a primitive that can be called by \
     PrimitiveGroup.
 
-    :param data: [x1, y1, x2, y2] where (x1, y1) and (x2, y2) are two \
-    points that belong to the line segment.
-    :type data: [float, float, float, float]
+    :param point1: first endpoint of the line segment [x1, y1].
+    :type point1: List[float]
+    :param point2: first endpoint of the line segment [x2, y2].
+    :type point2: List[float]
     :param edge_style: for customization
     :type edge_style: EdgeStyle
     """
 
-    def __init__(self, data: List[float], edge_style: EdgeStyle = None,
+    def __init__(self, point1: List[float], point2: List[float],
+                 edge_style: EdgeStyle = None,
                  name: str = ''):
-        self.data = data
+        self.data = point1 + point2
         if edge_style is None:
             self.edge_style = EdgeStyle()
         else:
@@ -383,8 +369,8 @@ class Circle2D(PlotDataObject):
         self.edge_style = edge_style
         self.surface_style = surface_style
         self.r = r
-        self.cy = cy
         self.cx = cx
+        self.cy = cy
         PlotDataObject.__init__(self, type_='circle', name=name)
 
     def bounding_box(self):
@@ -492,10 +478,10 @@ class Tooltip(PlotDataObject):
     clicking on points.
     A tooltip object is instantiated by Scatter and Dataset classes.
 
-    :param to_disp_attribute_names: a list containing the attributes \
+    :param attributes: a list containing the attributes \
     you want to display. Attributes must be taken from Dataset's or \
     Scatter's elements.
-    :type to_disp_attribute_names: List[str]
+    :type attributes: List[str]
     :param surface_style: for customizing the tooltip's interior
     :type surface_style: SurfaceStyle
     :param text_style: for customizing its text
@@ -505,11 +491,11 @@ class Tooltip(PlotDataObject):
     :type tooltip_radius: float
     """
 
-    def __init__(self, to_disp_attribute_names: List[str],
+    def __init__(self, attributes: List[str],
                  surface_style: SurfaceStyle = None,
-                 text_style: TextStyle = None, tooltip_radius: float = 5,
+                 text_style: TextStyle = None, tooltip_radius: float = None,
                  name: str = ''):
-        self.to_disp_attribute_names = to_disp_attribute_names
+        self.attributes = attributes
         self.surface_style = surface_style
         if surface_style is None:
             self.surface_style = SurfaceStyle(color_fill=colors.LIGHTBLUE,
@@ -541,12 +527,12 @@ class Dataset(PlotDataObject):
     :param display_step: a value that limits the number of points \
     displayed.
     :type display_step: int
-    :param to_disp_attribute_names: [attribute_x, attribute_y] where \
+    :param attribute_names: [attribute_x, attribute_y] where \
     attribute_x is the attribute displayed on x-axis and attribute_y \
     is the attribute displayed on y-axis.
-    :type to_disp_attribute_names: [str, str]
+    :type attribute_names: [str, str]
     """
-    to_disp_attribute_names = None
+    attribute_names = None
 
     def __init__(self, elements=None,
                  edge_style: EdgeStyle = None, tooltip: Tooltip = None,
@@ -571,19 +557,19 @@ class Graph2D(PlotDataObject):
 
     :param graphs: a list of Datasets
     :type graphs: List[Dataset]
-    :param to_disp_attribute_names: [attribute_x, attribute_y] where \
-    attribute_x is the attribute displayed on x-axis and attribute_y \
-    is the attribute displayed on y-axis
-    :type to_disp_attribute_names: [str, str]
+    :param x_variable: variable that you want to display on x axis
+    :type x_variable: str
+    :param y_variable: variable that you want to display on y axis
+    :type y_variable: str
     :param axis: an object containing all information needed for \
     drawing axis
     :type axis: Axis
     """
 
-    def __init__(self, graphs: List[Dataset], to_disp_attribute_names,
+    def __init__(self, graphs: List[Dataset], x_variable: str, y_variable:str,
                  axis: Axis = None, name: str = ''):
         self.graphs = graphs
-        self.to_disp_attribute_names = to_disp_attribute_names
+        self.attribute_names = [x_variable, y_variable]
         if axis is None:
             self.axis = Axis()
         else:
@@ -593,7 +579,7 @@ class Graph2D(PlotDataObject):
     def mpl_plot(self):
         # axs = plt.subplots(len(self.graphs))
         _, ax = plt.subplots()
-        xname, yname = self.to_disp_attribute_names[:2]
+        xname, yname = self.attribute_names[:2]
         for dataset in self.graphs:
             x = []
             y = []
@@ -605,6 +591,7 @@ class Graph2D(PlotDataObject):
         ax.set_ylabel(yname)
         return ax
 
+
 class Scatter(PlotDataObject):
     """
     A class for drawing scatter plots.
@@ -612,10 +599,10 @@ class Scatter(PlotDataObject):
     :param elements: A list of vectors. Vectors must have the same \
     attributes (ie the same keys)
     :type elements: List[dict]
-    :param to_disp_attribute_names: [attribute_x, attribute_y] where \
-    attribute_x is the attribute displayed on x-axis and attribute_y \
-    is the attribute displayed on y-axis
-    :type to_disp_attribute_names: [str, str]
+    :param x_variable: variable that you want to display on x axis
+    :type x_variable: str
+    :param y_variable: variable that you want to display on y axis
+    :type y_variable: str
     :param tooltip: an object containing all information needed for \
     drawing tooltips
     :type tooltip: Tooltip
@@ -626,19 +613,19 @@ class Scatter(PlotDataObject):
     :type axis: Axis
     """
 
-    def __init__(self, tooltip: Tooltip,
-                 to_disp_attribute_names: List[str],
+    def __init__(self, x_variable: str, y_variable: str,
+                 tooltip: Tooltip = None,
                  point_style: PointStyle = None,
                  elements: List[Any] = None, axis: Axis = None,
                  name: str = ''):
         self.tooltip = tooltip
-        self.to_disp_attribute_names = to_disp_attribute_names
+        self.attribute_names = [x_variable, y_variable]
         self.point_style = point_style
         if not elements:
             self.elements = []
         else:
             self.elements = elements
-        if axis:
+        if not axis:
             self.axis = Axis()
         else:
             self.axis = axis
@@ -649,7 +636,7 @@ class Scatter(PlotDataObject):
 class Arc2D(PlotDataObject):
     """
     A class for drawing arcs. Arc2D is a primitive and can be \
-    instantiated by PrimitiveGroup.
+    instantiated by PrimitiveGroup. By default, the arc is drawn anticlockwise.
 
     :param cx: the arc center's x position
     :type cx: float
@@ -744,9 +731,8 @@ class Contour2D(PlotDataObject):
         for plot_data_primitive in self.plot_data_primitives:
             if hasattr(plot_data_primitive, 'bounding_box'):
                 bb = plot_data_primitive.bounding_box()
-                xmin, xmax, ymin, ymax = min(xmin, bb[0]), max(xmax,
-                                                               bb[1]), min(
-                    ymin, bb[2]), max(ymax, bb[3])
+                xmin, xmax, ymin, ymax = min(xmin, bb[0]), max(xmax,bb[1]), \
+                                         min(ymin, bb[2]), max(ymax, bb[3])
 
         return xmin, xmax, ymin, ymax
 
@@ -803,9 +789,9 @@ class PrimitiveGroup(PlotDataObject):
     A class for drawing multiple primitives and contours inside a canvas.
 
     :param primitives: a list of Contour2D, Arc2D, LineSegment2D, \
-    Circle2D or Line2D
+    Circle2D, Line2D or MultipleLabels
     :type primitives: List[Union[Contour2D, Arc2D, LineSegment2D, \
-    Circle2D, Line2D]]
+    Circle2D, Line2D, MultipleLabels]]
     """
 
     def __init__(self, primitives: List[Union[Contour2D, Arc2D, LineSegment2D,
@@ -853,28 +839,36 @@ class PrimitiveGroupsContainer(PlotDataObject):
     :param coords: In the same way as sizes but for coordinates.
     :type coords: List[Tuple[float, float]]
     :param associated_elements: A list containing the associated \
-    elements indices. associated_elements[i] is assoaciated with \
+    elements indices. associated_elements[i] is associated with \
     primitive_groups[i]. It only works if this object is inside a \
     MultiplePlots.
     :type associated_elements: List[int]
-    :param to_disp_attribute_names: A list containing the attribute \
-    names to be displayed on axis. It may contain one or two names. ex:\
-     ['mass'] or ['length', 'mass']. Set it to None for no axis.
-    :type to_disp_attribute_names: List[str]
+    :param x_variable: variable that you want to display on x axis
+    :type x_variable: str
+    :param y_variable: variable that you want to display on y axis
+    :type y_variable: str
     """
 
     def __init__(self, primitive_groups: List[PrimitiveGroup],
                  sizes: List[Tuple[float, float]] = None,
                  coords: List[Tuple[float, float]] = None,
                  associated_elements: List[int] = None,
-                 to_disp_attribute_names: List[str] = None,
+                 x_variable: str = None, y_variable: str = None,
                  name: str = ''):
+        for i, value in enumerate(primitive_groups):
+            if not isinstance(value, PrimitiveGroup):
+                primitive_groups[i] = PrimitiveGroup(primitives=value)
         self.primitive_groups = primitive_groups
         self.sizes = sizes
         self.coords = coords
-        if to_disp_attribute_names:
+        if x_variable or y_variable:
+            attribute_names = []
+            if x_variable:
+                attribute_names.append(x_variable)
+            if y_variable:
+                attribute_names.append(y_variable)
             self.association = {'associated_elements': associated_elements,
-                                'to_disp_attribute_names': to_disp_attribute_names}
+                                'attribute_names': attribute_names}
         PlotDataObject.__init__(self, type_='primitivegroupcontainer',
                                 name=name)
 
@@ -891,9 +885,9 @@ class ParallelPlot(PlotDataObject):
     :param disposition: either 'vertical' or 'horizontal' depending on \
     how you want the initial disposition to be.
     :type disposition: str
-    :param to_disp_attribute_names: a list on attribute names you want \
+    :param axes: a list on attribute names you want \
     to display as axis on this parallel plot.
-    :type to_disp_attribute_names: List[str]
+    :type axes: List[str]
     :param rgbs: a list of rgb255 colors for color interpolation. Color\
      interpolation is enabled when clicking on an axis.
     :type rgbs: List[Tuple[int, int, int]]
@@ -901,13 +895,13 @@ class ParallelPlot(PlotDataObject):
 
     def __init__(self, elements=None, edge_style: EdgeStyle = None,
                  disposition: str = None,
-                 to_disp_attribute_names: List[str] = None,
+                 axes: List[str] = None,
                  rgbs: List[Tuple[int, int, int]] = None,
                  name: str = ''):
         self.elements = elements
         self.edge_style = edge_style
         self.disposition = disposition
-        self.to_disp_attribute_names = to_disp_attribute_names
+        self.attribute_names = axes
         self.rgbs = rgbs
         PlotDataObject.__init__(self, type_='parallelplot', name=name)
 
@@ -946,6 +940,37 @@ class PointFamily(PlotDataObject):
         PlotDataObject.__init__(self, type_=None, name=name)
 
 
+class Histogram(PlotDataObject):
+    """
+    The Histogram object. This class can be instantiated in Multiplot.
+
+    :param x_variable: The name of x variable
+    :type x_variable: str
+    :param elements: A list of vectors.
+    :type elements: list(dict)
+    :param axis: axis style customization. The number of points cannot\
+    be changed for a histogram
+    :type axis: Axis
+    :param graduation_nb: the number of graduations on the x axis. Default = 6.\
+    This parameter doesn't make sense for a non float x axis.
+    :type graduation_nb: float
+    :param edge_style: histogram rectangles edge style
+    :type edge_style: EdgeStyle
+    :param surface_style: histogram rectangle surface style
+    :type surface_style: SurfaceStyle
+    """
+
+    def __init__(self, x_variable: str, elements=None, axis: Axis = None, graduation_nb: float = None,
+                 edge_style: EdgeStyle = None, surface_style: SurfaceStyle = None, name: str = ''):
+        self.x_variable = x_variable
+        self.elements = elements
+        self.axis = axis
+        self.graduation_nb = graduation_nb
+        self.edge_style = edge_style
+        self.surface_style = surface_style
+        PlotDataObject.__init__(self, type_='histogram', name=name)
+
+
 class MultiplePlots(PlotDataObject):
     """
     A class for drawing multiple PlotDataObjects (except MultiplePlots)\
@@ -1020,14 +1045,23 @@ def plot_canvas(plot_data_object: Subclass[PlotDataObject],
         template = templates.multiplot_template
     elif plot_type == 'primitivegroupcontainer':
         template = templates.primitive_group_container_template
+    elif plot_type == 'histogram':
+        template = templates.histogram_template
     else:
         raise NotImplementedError('Type {} not implemented'.format(plot_type))
 
-    lib_path = 'https://cdn.dessia.tech/js/plot-data/latest/core.js'
+    version = get_current_version()
+    cdn_url = 'https://cdn.dessia.tech/js/plot-data/{}/core.js'
+    lib_path = cdn_url.format(version)
     if debug_mode:
-        core_path = os.sep + os.path.join(
-            *sys.modules[__name__].__file__.split(os.sep)[:-2], 'lib',
-            'core.js')
+        # core_path = os.sep + os.path.join(
+        #     *sys.modules[__name__].__file__.split('/')[:-2], 'lib',
+        #     'core.js')
+        core_path = os.sep.join(os.getcwd().split(os.sep)[:-1] + ['dist', 'plot-data.js'])
+
+        # I added the line below since the one above that I commented didn't work for me on Windows 10.
+        # I'm going to fix it later on and if I forget to remove it, feel free to do so. Jeremie
+        # core_path = 'C:\\Users\\jch1\\Documents\\Github\\plot_data\\lib\\core.js'
 
         if not os.path.isfile(core_path):
             print('Local compiled core.js not found, fall back to CDN')
@@ -1096,3 +1130,18 @@ def bounding_box(plot_datas: Subclass[PlotDataObject]):
             ymin, ymax = min(ymin, bb[2]), max(ymax, bb[3])
 
     return xmin, xmax, ymin, ymax
+
+
+def get_current_version() -> str:
+    try:
+        package = sys.modules[sys.modules[__name__].__package__]
+        version = package.__version__
+
+        splitted_version = version.split(".")
+        if len(splitted_version) > 3:
+            splitted_version.pop()
+            splitted_version[2] = str(int(splitted_version[2]) - 1)
+        formatted_version = "v" + ".".join(splitted_version)
+        return formatted_version
+    except Exception:
+        return 'latest'
